@@ -43,10 +43,10 @@ def datetime_from_unix(time):
     try:
         # Fails for milliseconds
         return datetime.fromtimestamp(time, tz=timezone.utc)
-    except OSError:
+    except:
         try:
             return datetime.fromtimestamp(time/1000, tz=timezone.utc)
-        except OSError:
+        except:
             return None
 
 
